Revision History
================

0.1.4 (2016/03/26)
------------------

::

    Fixing deployment configuration.

0.1.1 (2016/03/26)
------------------

::

    Implement abstract interfaces.
    Code cleaned.
    Improve CI process.
    Add Documentation.

0.1.0 (2016/03/06)
------------------

::

    Creating application prototype - configure CI process

